@@ -2,7 +2,7 @@ from pydantic import BaseModel
 from typing import TypeVar, Generic, Optional, List, Any, Literal
 
 class Common500Response(BaseModel):
-    status: Literal['validateerror', 'neterror','dberror','cache server error','tokenerror','unknownerr','notlogin','permissiondenied','userbanned']
+    status: Literal['validateerror', 'neterror','dberror','cache server error','tokenerror','unknownerr','notlogin','permissiondenied','userbanned','modelnotexists']
     msg: Optional[str] = None
     data:Optional[Any]
 
