@@ -1,7 +1,7 @@
 
 from typing import Any
 from starlette.responses import JSONResponse
-from .xtjson import toJson,toBytesJson
+from .xtjson import toJson,toBytesJson,obj2dict
 
 
 class XTJsonResponse(JSONResponse):
@@ -21,7 +21,7 @@ class XTJsonResponse(JSONResponse):
         return toBytesJson(content,self.striplang)
 
 from .cache import cache
-from .CommonResponse import CommonResponse
+from .CommonResponse import CommonResponse,QueryShema
 from .CommonError import Common500Response,TokenException,PermissionException
 from .snowFlakeId import snowFlack
 from .encrypt import generateKey
