@@ -3,6 +3,7 @@ from pydantic import BaseModel
 from decimal import Decimal
 from typing import Any
 import orjson
+from sqlalchemy.engine import RowMapping
 def obj2dict(obj:Any,striplang='')->Any:#type: ignore
     if isinstance(obj,DeclarativeMeta):
         return obj.dict(striplang=striplang)
@@ -10,6 +11,9 @@ def obj2dict(obj:Any,striplang='')->Any:#type: ignore
         return obj.dict()
     elif isinstance(obj,Decimal):
         return str(obj)
+    elif isinstance(obj,RowMapping):
+        print('RowMapping:',obj)
+        return dict(obj)
     raise Exception("object are not jsonable")
 
 def toBytesJson(obj:Any,striplang:str='')->bytes:
